@@ -14,6 +14,7 @@ class FaceAnalyzer:
 
     def __init__(
             self,
+            es_object=None,
             es_url=DEFAULT_ES_URL,
             es_index=DEFAULT_ES_INDEX,
             es_vector_field="vector",
@@ -21,7 +22,9 @@ class FaceAnalyzer:
             es_value_field="value",
             es_nested_field_name="texta_face_vectors"
         ):
-        self.es = Elasticsearch(DEFAULT_ES_URL)
+        self.es = es_object
+        if not self.es:
+            self.es = Elasticsearch(DEFAULT_ES_URL)
         self.es_index = es_index
         self.es_vector_field = es_vector_field
         self.es_name_field = es_name_field
